Struct Cr
#[repr(transparent)]pub struct Cr(pub u32);Expand description
Clock control register
Tuple Fields
0: u32Implementations
impl Cr
impl Cr
pub const fn msirdy(&self) -> bool
pub const fn msirdy(&self) -> bool
MSI clock ready flag (After reset this bit will be read 1 once the MSI is ready)
pub const fn set_msirdy(&mut self, val: bool)
pub const fn set_msirdy(&mut self, val: bool)
MSI clock ready flag (After reset this bit will be read 1 once the MSI is ready)
pub const fn set_msipllen(&mut self, val: bool)
pub const fn set_msipllen(&mut self, val: bool)
MSI clock PLL enable
pub const fn set_msirgsel(&mut self, val: Msirgsel)
pub const fn set_msirgsel(&mut self, val: Msirgsel)
MSI range control selection
pub const fn set_msirange(&mut self, val: Msirange)
pub const fn set_msirange(&mut self, val: Msirange)
MSI clock ranges
pub const fn set_hsikeron(&mut self, val: bool)
pub const fn set_hsikeron(&mut self, val: bool)
HSI always enable for peripheral kernel clocks.
pub const fn hsirdy(&self) -> bool
pub const fn hsirdy(&self) -> bool
HSI clock ready flag. (After wakeup from Stop this bit will be read 1 once the HSI is ready)
pub const fn set_hsirdy(&mut self, val: bool)
pub const fn set_hsirdy(&mut self, val: bool)
HSI clock ready flag. (After wakeup from Stop this bit will be read 1 once the HSI is ready)
pub const fn set_hsiasfs(&mut self, val: bool)
pub const fn set_hsiasfs(&mut self, val: bool)
HSI automatic start from Stop
pub const fn set_hsikerdy(&mut self, val: bool)
pub const fn set_hsikerdy(&mut self, val: bool)
HSI kernel clock ready flag for peripherals requests.
pub const fn set_hserdy(&mut self, val: bool)
pub const fn set_hserdy(&mut self, val: bool)
HSE clock ready flag
pub const fn set_hsepre(&mut self, val: Hsepre)
pub const fn set_hsepre(&mut self, val: Hsepre)
HSE sysclk prescaler
pub const fn set_hsebyppwr(&mut self, val: bool)
pub const fn set_hsebyppwr(&mut self, val: bool)
Enable HSE VDDTCXO output on package pin PB0-VDDTCXO.
pub const fn set_pllrdy(&mut self, val: bool)
pub const fn set_pllrdy(&mut self, val: bool)
Main PLL clock ready flag